@@ -3,11 +3,16 @@
 # It is also provided as a convenience to those who want to deploy these URLs
 # elsewhere.
 
-from django.conf.urls import patterns, url
+from django.contrib import admin
+from django.conf.urls import patterns, url, include
 
 urlpatterns = patterns('djara.django.contrib.admin.views',
+
     url(r'^login/$', 'login', name='login'),
     url(r'^logout/$', 'logout', name='logout'),
+    url(r'^(?P<app_label>\w+)/$', admin.site.index, name='app_list'),
+    url(r'^jsi18n/$', admin.site.i18n_javascript, name='jsi18n'),
+    url(r'^$', admin.site.index, name='index'),
     # url(r'^password_change/$', 'django.contrib.auth.views.password_change', name='password_change'),
     # url(r'^password_change/done/$', 'django.contrib.auth.views.password_change_done', name='password_change_done'),
     # url(r'^password_reset/$', 'django.contrib.auth.views.password_reset', name='password_reset'),
@@ -20,3 +25,6 @@ urlpatterns = patterns('djara.django.contrib.admin.views',
     #     name='password_reset_confirm'),
     # url(r'^reset/done/$', 'django.contrib.auth.views.password_reset_complete', name='password_reset_complete'),
 )
+
+# Add the real url patterns of the admin
+urlpatterns += admin.site.get_urls()
\ No newline at end of file
